@@ -6,8 +6,8 @@
 ;;         Fanael Linithien <fanael4@gmail.com>
 ;; URL: https://github.com/purcell/package-lint
 ;; Keywords: lisp
-;; Package-Version: 0.26
-;; Package-Revision: 26b27201f127
+;; Package-Version: 20250828.1506
+;; Package-Revision: f990665a1b4c
 ;; Package-Requires: ((emacs "24.4") (let-alist "1.0.6"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -423,8 +423,10 @@ Instead it should use `user-emacs-directory' or `locate-user-emacs-file'."
   "Check the contents of the \"Package-Requires\" header.
 Return a list of well-formed dependencies, same as
 `package-lint--check-well-formed-dependencies'."
-  (let ((deps (package-lint--goto-header "Package-Requires")))
+  (let ((deps (package-lint--goto-header "Package-Requires" t)))
     (when deps
+      (when (listp deps)
+        (setq deps (mapconcat #'identity deps "")))
       (let ((position (point)))
         (condition-case err
             (pcase-let ((`(,parsed-deps . ,parse-end-pos) (read-from-string deps)))
@@ -576,7 +578,7 @@ required version PACKAGE-VERSION.  If not, raise an error for DEP-POS."
   (save-excursion
     (save-match-data
       (and (re-search-backward
-            (concat "(" (regexp-opt '("fboundp" "macrop")) "\\s-+#?'" (regexp-quote sym) "\\_>") (point-min) t)
+            (concat "(" (regexp-opt '("fboundp" "functionp" "macrop")) "\\s-+#?'" (regexp-quote sym) "\\_>") (point-min) t)
            (not (package-lint--inside-comment-or-string-p))))))
 
 (defun package-lint--map-regexp-match (regexp callback)
@@ -1163,7 +1165,12 @@ leading or trailing whitespace removed.
 If MULTILINE is non-nil, allow the header value to span lines, and return
 them as a list of strings."
   (goto-char (point-min))
-  (when (re-search-forward (concat (lm-get-header-re header-name) "\\(.*?\\) *$") (lm-code-mark) t)
+  (when (re-search-forward (concat (lm-get-header-re header-name) "\\(.*?\\) *$")
+                           (cond
+                            ((fboundp 'lm-code-start) (lm-code-start)) ; >=30
+                            ((fboundp 'lm-code-mark) (lm-code-mark))   ; <=29
+                            ((error "BUG: lm-code-{start,mark} disappeared")))
+                           t)
     (let ((start-pos (match-beginning 3))
           (val (match-string-no-properties 3)))
       (when multiline
@@ -1172,7 +1179,7 @@ them as a list of strings."
         (while (looking-at "^;+\\(\t\\|[\t\s]\\{2,\\}\\)\\(.+\\)")
           (push (match-string-no-properties 2) val)
           (forward-line 1))
-        (nreverse val))
+        (setq val (nreverse val)))
       (goto-char start-pos)
       val)))
 
